import React from 'react';
import PropTypes from 'prop-types';
import Spinner from 'react-native-spinkit';
import { StyledText } from './styled';
import useTheme from '../../hooks/useTheme';
const getSpinnerColor = (palette, variant) => {
    if (variant === 'brand' || variant === 'destructive' || variant === 'success') {
        return palette.getContrastText(palette.text.main);
    }
    if (variant === 'neutral') {
        return palette.background.highlight;
    }
    return palette.brand.main;
};
const ButtonContent = props => {
    const { variant, children, disabled, isLoading } = props;
    const { rainbow: { palette }, } = useTheme();
    if (isLoading) {
        return <Spinner type="Arc" size={30} color={getSpinnerColor(palette, variant)}/>;
    }
    if (typeof children === 'string' || typeof children === 'number') {
        return (<StyledText variant={variant} disabled={disabled} numberOfLines={1}>
                {children}
            </StyledText>);
    }
    return children;
};
ButtonContent.propTypes = {
    children: PropTypes.node,
    variant: PropTypes.oneOf([
        'base',
        'neutral',
        'brand',
        'outline-brand',
        'destructive',
        'success',
    ]),
    disabled: PropTypes.bool,
};
ButtonContent.defaultProps = {
    children: null,
    variant: 'base',
    disabled: false,
};
export default ButtonContent;
